==> imp-5.0.15.tgz: imp-5.0.15/lib/Search/Element/Personal.php <==
<?php
/**
 * This class handles the personal recipient search query.
 *
 * This query matches if one of the e-mails defined in the identities
 * matches the To/Cc/Bcc header of an email.
 *
 * Copyright 2010-2011 Horde LLC (http://www.horde.org/)
 *
 * See the enclosed file COPYING for license information (GPL). If you
 * did not receive this file, see http://www.horde.org/licenses/gpl.
 *
 * @author   Michael Slusarz <slusarz@horde.org>
 * @category Horde
 * @license  http://www.horde.org/licenses/gpl GPL
 * @package  IMP
 */
class IMP_Search_Element_Personal extends IMP_Search_Element
{
    /**
     * Constructor.
     *
     * @param boolean $not  If true, do a 'NOT' search of $text.
     */
    public function __construct($not = false)
    {
        /* Data element: (integer) Do a NOT search? */
        $this->_data = intval($not);
    }

    /**
     */
    public function createQuery($mbox, $queryob)
    {
        $and_ob = new Horde_Imap_Client_Search_Query();
        $identity = $GLOBALS['injector']->getInstance('IMP_Identity');

        foreach ($identity->getAllIdentityAddresses() as $val) {
            $ob = new Horde_Imap_Client_Search_Query();
            $ob->headerText('to', $val, $this->_data);
            $and_ob->orSearch(array($ob));

            $ob = new Horde_Imap_Client_Search_Query();
            $ob->headerText('cc', $val, $this->_data);
            $and_ob->orSearch(array($ob));

            $ob = new Horde_Imap_Client_Search_Query();
            $ob->headerText('bcc', $val, $this->_data);
            $and_ob->orSearch(array($ob));
        }

        $queryob->andSearch(array($and_ob));

        return $queryob;
    }

    /**
     */
    public function queryText()
    {
        return ($this->_data ? _("not") . ' ' : '') . _("Personal Messages");
    }

}

==> imp-5.0.23.tgz: imp-5.0.23/lib/Search/Element/Personal.php <==
<?php
/**
 * This class handles the personal recipient search query.
 *
 * This query matches if one of the e-mails defined in the identities
 * matches the To/Cc/Bcc header of an email.
 *
 * Copyright 2010-2012 Horde LLC (http://www.horde.org/)
 *
 * See the enclosed file COPYING for license information (GPL). If you
 * did not receive this file, see http://www.horde.org/licenses/gpl.
 *
 * @author   Michael Slusarz <slusarz@horde.org>
 * @category Horde
 * @license  http://www.horde.org/licenses/gpl GPL
 * @package  IMP
 */
class IMP_Search_Element_Personal extends IMP_Search_Element
{
    /**
     * Constructor.
     *
     * @param boolean $not  If true, do a 'NOT' search of $text.
     */
    public function __construct($not = false)
    {
        /* Data element: (integer) Do a NOT search? */
        $this->_data = intval(!empty($not));
    }

    /**
     */
    public function createQuery($mbox, $queryob)
    {
        $and_ob = new Horde_Imap_Client_Search_Query();
        $identity = $GLOBALS['injector']->getInstance('IMP_Identity');

        foreach ($identity->getAllIdentityAddresses() as $val) {
            $ob = new Horde_Imap_Client_Search_Query();
            $ob->headerText('to', $val, $this->_data);
            $and_ob->orSearch(array($ob));

            $ob = new Horde_Imap_Client_Search_Query();
            $ob->headerText('cc', $val, $this->_data);
            $and_ob->orSearch(array($ob));

            $ob = new Horde_Imap_Client_Search_Query();
            $ob->headerText('bcc', $val, $this->_data);
            $and_ob->orSearch(array($ob));
        }

        $queryob->andSearch(array($and_ob));

        return $queryob;
    }

    /**
     */
    public function queryText()
    {
        return ($this->_data ? _("not") . ' ' : '') . _("Personal Messages");
    }

}
